# Meta Model Extensions
Activate optional extensions to the meta model to support specific use cases and enterprise architecture management practices.
Extensions enhance the meta model by introducing additional elements. Designed according to enterprise architecture management best practices, these extensions address specific use cases and deliver added value without requiring manual configuration.
As an admin, you can activate optional extensions in the Optional Features and Early Access section in the administration area. After activation, you can customize attributes or add new ones to better align the meta model with your organization’s needs.
The table below lists optional extensions to the meta model.
Meta Model Extensions Extension | Description | Detailed Information
---|---|---
AI governance and adoption | This extension offers a structured framework for tracking, managing, and evaluating organizations' AI usage, risks, and potential. It helps organizations adopt best practices for AI governance, ensuring AI initiatives align with overall business strategies. It also facilitates visualization and assessment of AI technologies across the IT landscape. | [AI Governance Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.")
Digital Operational Resilience Act (DORA) | This extension helps you integrate DORA regulatory requirements with your IT and business architecture. It allows you to track, manage, and document compliance by linking DORA obligations to systems, processes, and vendors. This enables you to assess risks, test resilience, and respond quickly during disruptions. | [Digital Operational Resilience Act (DORA) Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-dora-extension?locale=en-US&state=PRODUCTION&version=CLOUD "An overview of fields, relations, and subtypes across application, IT component, business context, and provider fact sheets to support DORA compliance.")
Application total cost of ownership | This extension helps you to gain transparency into the total cost of ownership for applications. As a lightweight solution for cost management it also allows you to align architecture costs with strategic objectives through robust cost allocation and aggregation capabilities. | [Application Total Cost of Ownership (TCO) Extension](https://help.sap.com/docs/leanix/ea/application-total-cost-of-ownership-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Gain transparency into total cost of ownership with the extension that activates dedicated fields, calculations, as well as options for reports and KPIs for dashboards.")
AI agent | This extension helps you model and govern your organization's AI agents and MCP servers to track the adoption of your AI agent strategy. | [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.")
SAP suggestions in your landscape | This extension adds SAP suggestions for applications and AI agents to dedicated reports, allowing you to identify optimization opportunities. You can create fact sheets from suggestions. | [SAP Suggestions in Your Landscape Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/sap-suggestions?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional extension to the meta model to view SAP suggestions for AI agents and applications in reports.")


YesNo
Send
